# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p2beta1/proto/asset_service.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.asset_v1p2beta1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1p2beta1_dot_proto_dot_assets__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p2beta1/proto/asset_service.proto",
    package="google.cloud.asset.v1p2beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p2beta1B\021AssetServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\252\002\034Google.Cloud.Asset.V1p2Beta1\312\002\034Google\\Cloud\\Asset\\V1p2Beta1",
    serialized_pb=b'\n6google/cloud/asset_v1p2beta1/proto/asset_service.proto\x12\x1cgoogle.cloud.asset.v1p2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a/google/cloud/asset_v1p2beta1/proto/assets.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto"u\n\x11\x43reateFeedRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x35\n\x04\x66\x65\x65\x64\x18\x03 \x01(\x0b\x32".google.cloud.asset.v1p2beta1.FeedB\x03\xe0\x41\x02"F\n\x0eGetFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"\'\n\x10ListFeedsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02"F\n\x11ListFeedsResponse\x12\x31\n\x05\x66\x65\x65\x64s\x18\x01 \x03(\x0b\x32".google.cloud.asset.v1p2beta1.Feed"\x80\x01\n\x11UpdateFeedRequest\x12\x35\n\x04\x66\x65\x65\x64\x18\x01 \x01(\x0b\x32".google.cloud.asset.v1p2beta1.FeedB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"I\n\x11\x44\x65leteFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"f\n\x0cOutputConfig\x12G\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32,.google.cloud.asset.v1p2beta1.GcsDestinationH\x00\x42\r\n\x0b\x64\x65stination"-\n\x0eGcsDestination\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x42\x0c\n\nobject_uri""\n\x11PubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t"p\n\x10\x46\x65\x65\x64OutputConfig\x12M\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32/.google.cloud.asset.v1p2beta1.PubsubDestinationH\x00\x42\r\n\x0b\x64\x65stination"\xe9\x02\n\x04\x46\x65\x65\x64\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12?\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32).google.cloud.asset.v1p2beta1.ContentType\x12O\n\x12\x66\x65\x65\x64_output_config\x18\x05 \x01(\x0b\x32..google.cloud.asset.v1p2beta1.FeedOutputConfigB\x03\xe0\x41\x02:\x91\x01\xea\x41\x8d\x01\n\x1e\x63loudasset.googleapis.com/Feed\x12\x1fprojects/{project}/feeds/{feed}\x12\x1d\x66olders/{folder}/feeds/{feed}\x12)organizations/{organization}/feeds/{feed} \x01*I\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESOURCE\x10\x01\x12\x0e\n\nIAM_POLICY\x10\x02\x32\xbf\x06\n\x0c\x41ssetService\x12\x94\x01\n\nCreateFeed\x12/.google.cloud.asset.v1p2beta1.CreateFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed"1\x82\xd3\xe4\x93\x02""\x1d/v1p2beta1/{parent=*/*}/feeds:\x01*\xda\x41\x06parent\x12\x89\x01\n\x07GetFeed\x12,.google.cloud.asset.v1p2beta1.GetFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed",\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1p2beta1/{name=*/*/feeds/*}\xda\x41\x04name\x12\x9c\x01\n\tListFeeds\x12..google.cloud.asset.v1p2beta1.ListFeedsRequest\x1a/.google.cloud.asset.v1p2beta1.ListFeedsResponse".\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1p2beta1/{parent=*/*}/feeds\xda\x41\x06parent\x12\x97\x01\n\nUpdateFeed\x12/.google.cloud.asset.v1p2beta1.UpdateFeedRequest\x1a".google.cloud.asset.v1p2beta1.Feed"4\x82\xd3\xe4\x93\x02\'2"/v1p2beta1/{feed.name=*/*/feeds/*}:\x01*\xda\x41\x04\x66\x65\x65\x64\x12\x83\x01\n\nDeleteFeed\x12/.google.cloud.asset.v1p2beta1.DeleteFeedRequest\x1a\x16.google.protobuf.Empty",\x82\xd3\xe4\x93\x02\x1f*\x1d/v1p2beta1/{name=*/*/feeds/*}\xda\x41\x04name\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb8\x01\n com.google.cloud.asset.v1p2beta1B\x11\x41ssetServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p2beta1;asset\xaa\x02\x1cGoogle.Cloud.Asset.V1p2Beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\V1p2Beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1p2beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
    name="ContentType",
    full_name="google.cloud.asset.v1p2beta1.ContentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="RESOURCE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="IAM_POLICY", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1560,
    serialized_end=1633,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
CONTENT_TYPE_UNSPECIFIED = 0
RESOURCE = 1
IAM_POLICY = 2


_CREATEFEEDREQUEST = _descriptor.Descriptor(
    name="CreateFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_id",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.feed_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1p2beta1.CreateFeedRequest.feed",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=385,
    serialized_end=502,
)


_GETFEEDREQUEST = _descriptor.Descriptor(
    name="GetFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.GetFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.GetFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=504,
    serialized_end=574,
)


_LISTFEEDSREQUEST = _descriptor.Descriptor(
    name="ListFeedsRequest",
    full_name="google.cloud.asset.v1p2beta1.ListFeedsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p2beta1.ListFeedsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=576,
    serialized_end=615,
)


_LISTFEEDSRESPONSE = _descriptor.Descriptor(
    name="ListFeedsResponse",
    full_name="google.cloud.asset.v1p2beta1.ListFeedsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feeds",
            full_name="google.cloud.asset.v1p2beta1.ListFeedsResponse.feeds",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=617,
    serialized_end=687,
)


_UPDATEFEEDREQUEST = _descriptor.Descriptor(
    name="UpdateFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest.feed",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.asset.v1p2beta1.UpdateFeedRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=690,
    serialized_end=818,
)


_DELETEFEEDREQUEST = _descriptor.Descriptor(
    name="DeleteFeedRequest",
    full_name="google.cloud.asset.v1p2beta1.DeleteFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.DeleteFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=820,
    serialized_end=893,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.asset.v1p2beta1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.asset.v1p2beta1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1p2beta1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=895,
    serialized_end=997,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.asset.v1p2beta1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.asset.v1p2beta1.GcsDestination.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="object_uri",
            full_name="google.cloud.asset.v1p2beta1.GcsDestination.object_uri",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=999,
    serialized_end=1044,
)


_PUBSUBDESTINATION = _descriptor.Descriptor(
    name="PubsubDestination",
    full_name="google.cloud.asset.v1p2beta1.PubsubDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.cloud.asset.v1p2beta1.PubsubDestination.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1046,
    serialized_end=1080,
)


_FEEDOUTPUTCONFIG = _descriptor.Descriptor(
    name="FeedOutputConfig",
    full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="pubsub_destination",
            full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig.pubsub_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1p2beta1.FeedOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1082,
    serialized_end=1194,
)


_FEED = _descriptor.Descriptor(
    name="Feed",
    full_name="google.cloud.asset.v1p2beta1.Feed",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p2beta1.Feed.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_names",
            full_name="google.cloud.asset.v1p2beta1.Feed.asset_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1p2beta1.Feed.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1p2beta1.Feed.content_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_output_config",
            full_name="google.cloud.asset.v1p2beta1.Feed.feed_output_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\215\001\n\036cloudasset.googleapis.com/Feed\022\037projects/{project}/feeds/{feed}\022\035folders/{folder}/feeds/{feed}\022)organizations/{organization}/feeds/{feed} \001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1197,
    serialized_end=1558,
)

_CREATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_LISTFEEDSRESPONSE.fields_by_name["feeds"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri"]
)
_GCSDESTINATION.fields_by_name["uri"].containing_oneof = _GCSDESTINATION.oneofs_by_name[
    "object_uri"
]
_FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"].message_type = _PUBSUBDESTINATION
_FEEDOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"]
)
_FEEDOUTPUTCONFIG.fields_by_name[
    "pubsub_destination"
].containing_oneof = _FEEDOUTPUTCONFIG.oneofs_by_name["destination"]
_FEED.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_FEED.fields_by_name["feed_output_config"].message_type = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["CreateFeedRequest"] = _CREATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["GetFeedRequest"] = _GETFEEDREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsRequest"] = _LISTFEEDSREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsResponse"] = _LISTFEEDSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateFeedRequest"] = _UPDATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["DeleteFeedRequest"] = _DELETEFEEDREQUEST
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
DESCRIPTOR.message_types_by_name["PubsubDestination"] = _PUBSUBDESTINATION
DESCRIPTOR.message_types_by_name["FeedOutputConfig"] = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["Feed"] = _FEED
DESCRIPTOR.enum_types_by_name["ContentType"] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "CreateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Create asset feed request.
  
  
  Attributes:
      parent:
          Required. The name of the project/folder/organization where
          this feed should be created in. It can only be an organization
          number (such as “organizations/123”), a folder number (such as
          “folders/123”), a project ID (such as “projects/my-project-
          id”)“, or a project number (such as”projects/12345").
      feed_id:
          Required. This is the client-assigned asset feed identifier
          and it needs to be unique under a specific parent
          project/folder/organization.
      feed:
          Required. The feed details. The field ``name`` must be empty
          and it will be generated in the format of:
          projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.CreateFeedRequest)
    },
)
_sym_db.RegisterMessage(CreateFeedRequest)

GetFeedRequest = _reflection.GeneratedProtocolMessageType(
    "GetFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Get asset feed request.
  
  
  Attributes:
      name:
          Required. The name of the Feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.GetFeedRequest)
    },
)
_sym_db.RegisterMessage(GetFeedRequest)

ListFeedsRequest = _reflection.GeneratedProtocolMessageType(
    "ListFeedsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """List asset feeds request.
  
  
  Attributes:
      parent:
          Required. The parent project/folder/organization whose feeds
          are to be listed. It can only be using
          project/folder/organization number (such as “folders/12345”)“,
          or a project ID (such as”projects/my-project-id").
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.ListFeedsRequest)
    },
)
_sym_db.RegisterMessage(ListFeedsRequest)

ListFeedsResponse = _reflection.GeneratedProtocolMessageType(
    "ListFeedsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSRESPONSE,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      feeds:
          A list of feeds.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.ListFeedsResponse)
    },
)
_sym_db.RegisterMessage(ListFeedsResponse)

UpdateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Update asset feed request.
  
  
  Attributes:
      feed:
          Required. The new values of feed details. It must match an
          existing feed and the field ``name`` must be in the format of:
          projects/project_number/feeds/feed_id or
          folders/folder_number/feeds/feed_id or
          organizations/organization_number/feeds/feed_id.
      update_mask:
          Required. Only updates the ``feed`` fields indicated by this
          mask. The field mask must not be empty, and it must not
          contain fields that are immutable or only set by the server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.UpdateFeedRequest)
    },
)
_sym_db.RegisterMessage(UpdateFeedRequest)

DeleteFeedRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      name:
          Required. The name of the feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.DeleteFeedRequest)
    },
)
_sym_db.RegisterMessage(DeleteFeedRequest)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for export assets destination.
  
  
  Attributes:
      destination:
          Asset export destination.
      gcs_destination:
          Destination on Cloud Storage.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.OutputConfig)
    },
)
_sym_db.RegisterMessage(OutputConfig)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSDESTINATION,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """A Cloud Storage location.
  
  
  Attributes:
      object_uri:
          Required.
      uri:
          The uri of the Cloud Storage object. It’s the same uri that is
          used by gsutil. For example: “gs://bucket_name/object_name”.
          See `Viewing and Editing Object Metadata
          <https://cloud.google.com/storage/docs/viewing-editing-
          metadata>`__ for more information.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.GcsDestination)
    },
)
_sym_db.RegisterMessage(GcsDestination)

PubsubDestination = _reflection.GeneratedProtocolMessageType(
    "PubsubDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBSUBDESTINATION,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """A Cloud Pubsub destination.
  
  
  Attributes:
      topic:
          The name of the Cloud Pub/Sub topic to publish to. For
          example: ``projects/PROJECT_ID/topics/TOPIC_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.PubsubDestination)
    },
)
_sym_db.RegisterMessage(PubsubDestination)

FeedOutputConfig = _reflection.GeneratedProtocolMessageType(
    "FeedOutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEEDOUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for asset feed destination.
  
  
  Attributes:
      destination:
          Asset feed destination.
      pubsub_destination:
          Destination on Cloud Pubsub.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.FeedOutputConfig)
    },
)
_sym_db.RegisterMessage(FeedOutputConfig)

Feed = _reflection.GeneratedProtocolMessageType(
    "Feed",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEED,
        "__module__": "google.cloud.asset_v1p2beta1.proto.asset_service_pb2",
        "__doc__": """An asset feed used to export asset updates to a
  destinations. An asset feed filter controls what updates are exported.
  The asset feed must be created within a project, organization, or
  folder. Supported destinations are: Cloud Pub/Sub topics.
  
  
  Attributes:
      name:
          Required. The format will be
          projects/{project_number}/feeds/{client-
          assigned_feed_identifier} or
          folders/{folder_number}/feeds/{client-
          assigned_feed_identifier} or
          organizations/{organization_number}/feeds/{client-
          assigned_feed_identifier}  The client-assigned feed identifier
          must be unique within the parent project/folder/organization.
      asset_names:
          A list of the full names of the assets to receive updates. You
          must specify either or both of asset_names and asset_types.
          Only asset updates matching specified asset_names and
          asset_types are exported to the feed. For example: ``//compute
          .googleapis.com/projects/my_project_123/zones/zone1/instances/
          instance1``. See `Resource Names <https://cloud.google.com/api
          s/design/resource_names#full_resource_name>`__ for more info.
      asset_types:
          A list of types of the assets to receive updates. You must
          specify either or both of asset_names and asset_types. Only
          asset updates matching specified asset_names and asset_types
          are exported to the feed. For example:
          “compute.googleapis.com/Disk” See `Introduction to Cloud Asset
          Inventory <https://cloud.google.com/resource-
          manager/docs/cloud-asset-inventory/overview>`__ for all
          supported asset types.
      content_type:
          Asset content type. If not specified, no content but the asset
          name and type will be returned.
      feed_output_config:
          Required. Feed output configuration defining where the asset
          updates are published to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p2beta1.Feed)
    },
)
_sym_db.RegisterMessage(Feed)


DESCRIPTOR._options = None
_CREATEFEEDREQUEST.fields_by_name["parent"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed_id"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed"]._options = None
_GETFEEDREQUEST.fields_by_name["name"]._options = None
_LISTFEEDSREQUEST.fields_by_name["parent"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["feed"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["update_mask"]._options = None
_DELETEFEEDREQUEST.fields_by_name["name"]._options = None
_FEED.fields_by_name["name"]._options = None
_FEED.fields_by_name["feed_output_config"]._options = None
_FEED._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1p2beta1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=1636,
    serialized_end=2467,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.CreateFeed",
            index=0,
            containing_service=None,
            input_type=_CREATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b'\202\323\344\223\002""\035/v1p2beta1/{parent=*/*}/feeds:\001*\332A\006parent',
        ),
        _descriptor.MethodDescriptor(
            name="GetFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.GetFeed",
            index=1,
            containing_service=None,
            input_type=_GETFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1p2beta1/{name=*/*/feeds/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="ListFeeds",
            full_name="google.cloud.asset.v1p2beta1.AssetService.ListFeeds",
            index=2,
            containing_service=None,
            input_type=_LISTFEEDSREQUEST,
            output_type=_LISTFEEDSRESPONSE,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1p2beta1/{parent=*/*}/feeds\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.UpdateFeed",
            index=3,
            containing_service=None,
            input_type=_UPDATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002'2\"/v1p2beta1/{feed.name=*/*/feeds/*}:\001*\332A\004feed",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteFeed",
            full_name="google.cloud.asset.v1p2beta1.AssetService.DeleteFeed",
            index=4,
            containing_service=None,
            input_type=_DELETEFEEDREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\037*\035/v1p2beta1/{name=*/*/feeds/*}\332A\004name",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)
